==> dotnet9_9.0.105-9.0.4.orig.tar.xz: src/roslyn/src/Features/CSharp/Portable/Structure/Providers/OperatorDeclarationStructureProvider.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

using System.Threading;
using Microsoft.CodeAnalysis.CSharp.Syntax;
using Microsoft.CodeAnalysis.PooledObjects;
using Microsoft.CodeAnalysis.Structure;

namespace Microsoft.CodeAnalysis.CSharp.Structure;

internal class OperatorDeclarationStructureProvider : AbstractSyntaxNodeStructureProvider<OperatorDeclarationSyntax>
{
    protected override void CollectBlockSpans(
        SyntaxToken previousToken,
        OperatorDeclarationSyntax operatorDeclaration,
        ArrayBuilder<BlockSpan> spans,
        BlockStructureOptions options,
        CancellationToken cancellationToken)
    {
        CSharpStructureHelpers.CollectCommentBlockSpans(operatorDeclaration, spans, options);

        // fault tolerance
        if (operatorDeclaration.Body == null ||
            operatorDeclaration.Body.OpenBraceToken.IsMissing ||
            operatorDeclaration.Body.CloseBraceToken.IsMissing)
        {
            return;
        }

        SyntaxNodeOrToken current = operatorDeclaration;
        var nextSibling = current.GetNextSibling();

        // Check IsNode to compress blank lines after this node if it is the last child of the parent.
        //
        // Whitespace between operators is collapsed in Metadata as Source.
        var compressEmptyLines = options.IsMetadataAsSource
            && (!nextSibling.IsNode || nextSibling.IsKind(SyntaxKind.OperatorDeclaration));

        spans.AddIfNotNull(CSharpStructureHelpers.CreateBlockSpan(
            operatorDeclaration,
            operatorDeclaration.ParameterList.GetLastToken(includeZeroWidth: true),
            compressEmptyLines: compressEmptyLines,
            autoCollapse: true,
            type: BlockTypes.Member,
            isCollapsible: true));
    }
}

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/roslyn/src/Features/CSharp/Portable/Structure/Providers/OperatorDeclarationStructureProvider.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

using System.Threading;
using Microsoft.CodeAnalysis.CSharp.Syntax;
using Microsoft.CodeAnalysis.PooledObjects;
using Microsoft.CodeAnalysis.Structure;

namespace Microsoft.CodeAnalysis.CSharp.Structure;

internal sealed class OperatorDeclarationStructureProvider : AbstractSyntaxNodeStructureProvider<OperatorDeclarationSyntax>
{
    protected override void CollectBlockSpans(
        SyntaxToken previousToken,
        OperatorDeclarationSyntax operatorDeclaration,
        ArrayBuilder<BlockSpan> spans,
        BlockStructureOptions options,
        CancellationToken cancellationToken)
    {
        CSharpStructureHelpers.CollectCommentBlockSpans(operatorDeclaration, spans, options);

        // fault tolerance
        if (operatorDeclaration.Body == null ||
            operatorDeclaration.Body.OpenBraceToken.IsMissing ||
            operatorDeclaration.Body.CloseBraceToken.IsMissing)
        {
            return;
        }

        SyntaxNodeOrToken current = operatorDeclaration;
        var nextSibling = current.GetNextSibling();

        // Check IsNode to compress blank lines after this node if it is the last child of the parent.
        //
        // Whitespace between operators is collapsed in Metadata as Source.
        var compressEmptyLines = options.IsMetadataAsSource
            && (!nextSibling.IsNode || nextSibling.IsKind(SyntaxKind.OperatorDeclaration));

        spans.AddIfNotNull(CSharpStructureHelpers.CreateBlockSpan(
            operatorDeclaration,
            operatorDeclaration.ParameterList.GetLastToken(includeZeroWidth: true),
            compressEmptyLines: compressEmptyLines,
            autoCollapse: true,
            type: BlockTypes.Member,
            isCollapsible: true));
    }
}
